<?php

namespace App\Http\Controllers\Auth;

use App\User;
use App\Info; 
use App\Pivot; 
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Foundation\Auth\RegistersUsers;
use GuzzleHttp\Client; 

class RegisterController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Register Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles the registration of new users as well as their
    | validation and creation. By default this controller uses a trait to
    | provide this functionality without requiring any additional code.
    |
    */

    use RegistersUsers;

    /**
     * Where to redirect users after registration.
     *
     * @var string
     */
    protected $redirectTo = '/';

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('guest');
    }

    /**
     * Get a validator for an incoming registration request.
     *
     * @param  array  $data
     * @return \Illuminate\Contracts\Validation\Validator
     */
    protected function validator(array $data)
    {
        return Validator::make($data, [
            'name' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:users'],
            'password' => ['required', 'string', 'min:8', 'confirmed'],
        ]);
    }
    

    /**
     * Create a new user instance after a valid registration.
     *
     * @param  array  $data
     * @return \App\User
     */
    protected function create(array $data)
    {
         // Create a new user
         $user = User::create([
            'name' => $data['name'],
            'email' => $data['email'],
            'password' => Hash::make($data['password']),
        ]);

        // Use Guzzle to fetch data from the specified link
        $client = new Client();
        $response = $client->get('https://pivotcontrol.ritecontrol.com/RecipeFiles/6BjzkHoN46if.json');

        if ($response->getStatusCode() == 200) {
            $jsonData = json_decode($response->getBody(), true);

            // Save the fetched data to the 'infos' table with user_id
            Info::create([
                'user_id' => $user->id,
                'Version' => $jsonData['Info']['Version'],
                'ProjectName' => $jsonData['Info']['ProjectName'],
                'PivotCount' => $jsonData['Info']['PivotCount'],
                'PumpProject' => $jsonData['Info']['PumpProject'],
                'PumpProjectName' => $jsonData['Info']['PumpProjectName'],
                'Maps' => $jsonData['Info']['Maps'],
                'MapsName' => $jsonData['Info']['MapsName'],
            ]);
        }

        return $user;
    }
}